News
====

Lists of changes between versions.


1.0.0
-----
* Minor: Use cli from bouillon instead of boil.py.
* Minor: Support Python 3.13.

0.3.0
------
* Major: Check if linters are installed instead of looking in pyproject.toml.

0.2.0
-----
* Improved testing and docstrings

0.1.0
-----
* Initial release
